@@ -1,35 +1,30 @@
+from __future__ import annotations
+
 from unittest import mock
 
 import pytest
 
-from hcloud.actions.client import BoundAction
-from hcloud.datacenters.client import BoundDatacenter
-from hcloud.datacenters.domain import Datacenter
-from hcloud.firewalls.client import BoundFirewall
-from hcloud.firewalls.domain import Firewall
-from hcloud.floating_ips.client import BoundFloatingIP
-from hcloud.images.client import BoundImage
-from hcloud.images.domain import Image
-from hcloud.isos.client import BoundIso
-from hcloud.isos.domain import Iso
-from hcloud.locations.domain import Location
-from hcloud.networks.client import BoundNetwork
-from hcloud.networks.domain import Network
-from hcloud.placement_groups.client import BoundPlacementGroup
-from hcloud.placement_groups.domain import PlacementGroup
-from hcloud.server_types.client import BoundServerType
-from hcloud.server_types.domain import ServerType
-from hcloud.servers.client import BoundServer, ServersClient
-from hcloud.servers.domain import (
+from hcloud.actions import BoundAction
+from hcloud.datacenters import BoundDatacenter, Datacenter
+from hcloud.firewalls import BoundFirewall, Firewall
+from hcloud.floating_ips import BoundFloatingIP
+from hcloud.images import BoundImage, Image
+from hcloud.isos import BoundIso, Iso
+from hcloud.locations import Location
+from hcloud.networks import BoundNetwork, Network
+from hcloud.placement_groups import BoundPlacementGroup, PlacementGroup
+from hcloud.server_types import BoundServerType, ServerType
+from hcloud.servers import (
+    BoundServer,
     IPv4Address,
     IPv6Network,
     PrivateNet,
     PublicNetwork,
     PublicNetworkFirewall,
     Server,
+    ServersClient,
 )
-from hcloud.volumes.client import BoundVolume
-from hcloud.volumes.domain import Volume
+from hcloud.volumes import BoundVolume, Volume
 
 
 class TestBoundServer:
@@ -152,6 +147,7 @@ class TestBoundServer:
 
         assert len(actions) == 1
         assert isinstance(actions[0], BoundAction)
+        assert actions[0]._client == hetzner_client.actions
         assert actions[0].id == 13
         assert actions[0].command == "start_server"
 
@@ -172,6 +168,7 @@ class TestBoundServer:
 
         assert len(actions) == 1
         assert isinstance(actions[0], BoundAction)
+        assert actions[0]._client == hetzner_client.actions
         assert actions[0].id == 13
         assert actions[0].command == "start_server"
 
@@ -609,11 +606,17 @@ class TestServersClient:
         )
 
         bound_server = response.server
+        bound_action = response.action
 
         assert bound_server._client is servers_client
         assert bound_server.id == 1
         assert bound_server.name == "my-server"
 
+        assert isinstance(bound_action, BoundAction)
+        assert bound_action._client == servers_client._client.actions
+        assert bound_action.id == 1
+        assert bound_action.command == "create_server"
+
     def test_create_with_location(self, servers_client, response_create_simple_server):
         servers_client._client.request.return_value = response_create_simple_server
         response = servers_client.create(
@@ -1223,3 +1226,53 @@ class TestServersClient:
         assert action.id == 1
         assert action.progress == 0
         assert action.command == "change_alias_ips"
+
+    def test_actions_get_by_id(self, servers_client, response_get_actions):
+        servers_client._client.request.return_value = {
+            "action": response_get_actions["actions"][0]
+        }
+        action = servers_client.actions.get_by_id(13)
+
+        servers_client._client.request.assert_called_with(
+            url="/servers/actions/13", method="GET"
+        )
+
+        assert isinstance(action, BoundAction)
+        assert action._client == servers_client._client.actions
+        assert action.id == 13
+        assert action.command == "start_server"
+
+    def test_actions_get_list(self, servers_client, response_get_actions):
+        servers_client._client.request.return_value = response_get_actions
+        result = servers_client.actions.get_list()
+
+        servers_client._client.request.assert_called_with(
+            url="/servers/actions",
+            method="GET",
+            params={},
+        )
+
+        actions = result.actions
+        assert result.meta is None
+
+        assert len(actions) == 1
+        assert isinstance(actions[0], BoundAction)
+        assert actions[0]._client == servers_client._client.actions
+        assert actions[0].id == 13
+        assert actions[0].command == "start_server"
+
+    def test_actions_get_all(self, servers_client, response_get_actions):
+        servers_client._client.request.return_value = response_get_actions
+        actions = servers_client.actions.get_all()
+
+        servers_client._client.request.assert_called_with(
+            url="/servers/actions",
+            method="GET",
+            params={"page": 1, "per_page": 50},
+        )
+
+        assert len(actions) == 1
+        assert isinstance(actions[0], BoundAction)
+        assert actions[0]._client == servers_client._client.actions
+        assert actions[0].id == 13
+        assert actions[0].command == "start_server"
